searchData={"items":[{"type":"module","title":"Mistral","doc":"Client for the Mistral AI API.\n\nThis library provides a simple and convenient way to integrate with Mistral's\nAPI, allowing you to use their powerful language models in your Elixir applications.","ref":"Mistral.html"},{"type":"function","title":"Mistral.chat/2","doc":"Chat with a Mistral model. Send messages and get a completion from the model.","ref":"Mistral.html#chat/2"},{"type":"function","title":"Options - Mistral.chat/2","doc":"- `:model` - The model to use for generating the response (required)\n- `:messages` - List of messages in the conversation (required)\n- `:temperature` - Controls randomness (0.0 to 1.0)\n- `:max_tokens` - Maximum number of tokens to generate\n- `:stream` - When true, returns a stream of partial response chunks\n- `:tools` - List of tools available to the model. Each tool must be a map with:\n  * `:type` set to \"function\"\n  * `:function` containing function details\n- `:tool_choice` - How to choose tools","ref":"Mistral.html#chat/2-options"},{"type":"function","title":"Examples - Mistral.chat/2","doc":"iex> Mistral.chat(client, [\n    ...>   model: \"mistral-small-latest\",\n    ...>   messages: [\n    ...>     %{role: \"user\", content: \"Write a haiku.\"}\n    ...>   ]\n    ...> ])\n    {:ok, %{\"choices\" => [%{\"message\" => %{\"content\" => \"Nature's whisper soft...\"}}], ...}}\n\n    # Stream the response\n    iex> {:ok, stream} = Mistral.chat(client, [\n    ...>   model: \"mistral-small-latest\",\n    ...>   messages: [%{role: \"user\", content: \"Write a haiku.\"}],\n    ...>   stream: true\n    ...> ])\n    iex> Enum.to_list(stream)\n    [%{\"choices\" => [%{\"delta\" => ...}]}, ...]","ref":"Mistral.html#chat/2-examples"},{"type":"function","title":"Tool Example - Mistral.chat/2","doc":"iex> Mistral.chat(client, [\n    ...>   model: \"mistral-large-latest\",\n    ...>   messages: [%{role: \"user\", content: \"What is the weather?\"}],\n    ...>   tools: [\n    ...>     %{\n    ...>       type: \"function\",\n    ...>       function: %{\n    ...>         name: \"get_weather\",\n    ...>         description: \"Fetches current weather\",\n    ...>         parameters: %{type: \"object\", properties: %{}}\n    ...>       }\n    ...>     }\n    ...>   ],\n    ...>   tool_choice: \"auto\"\n    ...> ])","ref":"Mistral.html#chat/2-tool-example"},{"type":"type","title":"Mistral.client/0","doc":"Client struct","ref":"Mistral.html#t:client/0"},{"type":"function","title":"Mistral.embed/2","doc":"Generate embeddings for the given input using a specified model.","ref":"Mistral.html#embed/2"},{"type":"function","title":"Options - Mistral.embed/2","doc":"- `:model` - The model to use for generating embeddings (default: \"mistral-embed\")\n- `:input` - Text or list of texts to generate embeddings for","ref":"Mistral.html#embed/2-options"},{"type":"function","title":"Examples - Mistral.embed/2","doc":"iex> Mistral.embed(client, input: \"Hello, world!\")\n    {:ok, %{\"data\" => [%{\"embedding\" => [...]}]}}\n\n    iex> Mistral.embed(client, input: [\"First text\", \"Second text\"])\n    {:ok, %{\"data\" => [%{\"embedding\" => [...]}, %{\"embedding\" => [...]}]}}","ref":"Mistral.html#embed/2-examples"},{"type":"function","title":"Mistral.init/0","doc":"Creates a new Mistral API client using the API key set in your application's config.\n\n```elixir\nconfig :mistral, :api_key, \"your-api-key\"\n```\n\nIf given, a keyword list of options will be passed to `Req.new/1`.","ref":"Mistral.html#init/0"},{"type":"function","title":"Mistral.init/1","doc":"","ref":"Mistral.html#init/1"},{"type":"function","title":"Mistral.init/2","doc":"Creates a new Mistral API client with the given API key.\n\nOptionally, a keyword list of options can be passed through to `Req.new/1`.","ref":"Mistral.html#init/2"},{"type":"type","title":"Mistral.response/0","doc":"Client response","ref":"Mistral.html#t:response/0"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}